;; Generated package description from org-real.el  -*- no-byte-compile: t -*-
(define-package "org-real" "1.0.9" "Keep track of real things as org-mode links" '((emacs "26.1") (boxy "1.1") (org "9.3")) :commit "b6df63b9c8f19c32367b03791ca47410708a10e1" :authors '(("Amy Grinn" . "grinn.amy@gmail.com")) :maintainer '("Amy Grinn" . "grinn.amy@gmail.com") :keywords '("tools") :url "https://gitlab.com/grinn.amy/org-real")
